@@ -1,5 +1,5 @@
 package HackaMol;
-$HackaMol::VERSION = '0.032';
+$HackaMol::VERSION = '0.033';
 #ABSTRACT: HackaMol: Object-Oriented Library for Molecular Hacking
 use 5.008;
 use Moose;
@@ -22,7 +22,7 @@ with 'HackaMol::Roles::NameRole',
 
 sub pdbid_mol {
   my $self  = shift;
-  my $pdbid = shift || croak "pass pdbid";
+  my $pdbid = shift || croak "Croak on passing pdbid, e.g. 2cba";
   my ($file,$rc) = $self->getstore_pdbid($pdbid);
   return($self->read_file_mol($file));
 }
@@ -218,7 +218,8 @@ sub find_bonds_brute {
 }
 
 sub group_rot {
-  #no pod yet
+  # no pod yet
+  # this method walks out from the two atoms in a bond and returns a group
   my $self  = shift;
   my $mol   = shift;
   my $bond  = shift;
@@ -290,7 +291,7 @@ HackaMol - HackaMol: Object-Oriented Library for Molecular Hacking
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 DESCRIPTION
 
