@@ -1,13 +1,15 @@
 package HackaMol::Atom;
-$HackaMol::Atom::VERSION = '0.032';
+$HackaMol::Atom::VERSION = '0.033';
 #ABSTRACT: HackaMol Atom Class
 use 5.008;
 use Moose;
 use namespace::autoclean;
 use Carp;
 use MooseX::StrictConstructor;
-#use MooseX::Storage;
-#with Storage( 'io' => 'StorableFile' ),
+
+use MooseX::Storage;
+with Storage('format' => 'JSON', 'io' => 'File');
+
 with  'HackaMol::Roles::NameRole', 
       'HackaMol::Roles::PhysVecMVRRole',
       'HackaMol::Roles::PdbRole',  
@@ -189,7 +191,7 @@ HackaMol::Atom - HackaMol Atom Class
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -336,6 +338,14 @@ L<Chemistry::Atom>
 
 =item * L<HackaMol::Roles::QmAtomRole>
 
+=item * L<MooseX::Storage::Basic>
+
+=item * L<MooseX::Storage::Basic|MooseX::Storage::Format::JSON|MooseX::Storage::IO::File>
+
+=item * L<MooseX::Storage::Format::JSON>
+
+=item * L<MooseX::Storage::IO::File>
+
 =back
 
 =head1 AUTHOR
