@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.032';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.033';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -8,6 +8,9 @@ use Math::Vector::Real;
 use FileHandle;
 use Scalar::Util 'reftype';
 
+use MooseX::Storage;
+with Storage( 'format' => 'JSON', 'io' => 'File', traits => ['OnlyWhenBuilt'] );
+
 my $angste_debye = 4.80320;
 
 has 'atoms' => (
@@ -382,7 +385,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -634,6 +637,22 @@ L<HackaMol::Dihedral>
 
 =back
 
+=head1 CONSUMES
+
+=over 4
+
+=item * L<MooseX::Storage::Basic>
+
+=item * L<MooseX::Storage::Basic|MooseX::Storage::Format::JSON|MooseX::Storage::IO::File|MooseX::Storage::Traits::OnlyWhenBuilt>
+
+=item * L<MooseX::Storage::Format::JSON>
+
+=item * L<MooseX::Storage::IO::File>
+
+=item * L<MooseX::Storage::Traits::OnlyWhenBuilt>
+
+=back
+
 =head1 AUTHOR
 
 Demian Riccardi <demianriccardi@gmail.com>
