@@ -1,5 +1,5 @@
 package HackaMol::Roles::PdbRole;
-$HackaMol::Roles::PdbRole::VERSION = '0.032';
+$HackaMol::Roles::PdbRole::VERSION = '0.033';
 #ABSTRACT: PdbRole of lazy attributes for HackaMol atoms
 use Moose::Role;
 use Carp;
@@ -34,6 +34,148 @@ has 'iatom',       is => 'rw', isa => 'Int', lazy => 1, default => 0;
 has 'resid',       is => 'rw', isa => 'Int', lazy => 1, default => 1;
 has 'serial',      is => 'rw', isa => 'Int', lazy => 1, default => 1;
 
+#lifted from Bio::PDB::Structure::Atom. Thank you, Raul Alcantara Aragon!
+
+
+my %pdb_atom_names = (
+    'C'    => ' C  ',
+    'C1'   => ' C1 ',
+    'C1A'  => ' C1A',
+    'C1B'  => ' C1B',
+    'C1C'  => ' C1C',
+    'C1D'  => ' C1D',
+    'C2'   => ' C2 ',
+    'C2A'  => ' C2A',
+    'C2B'  => ' C2B',
+    'C2C'  => ' C2C',
+    'C2D'  => ' C2D',
+    'C3'   => ' C3 ',
+    'C3A'  => ' C3A',
+    'C3B'  => ' C3B',
+    'C3C'  => ' C3C',
+    'C3D'  => ' C3D',
+    'C4'   => ' C4 ',
+    'C4A'  => ' C4A',
+    'C4A'  => ' C4A',
+    'C4B'  => ' C4B',
+    'C4C'  => ' C4C',
+    'C4D'  => ' C4D',
+    'C5'   => ' C5 ',
+    'C6'   => ' C6 ',
+    'CA'   => ' CA ',
+    'CAA'  => ' CAA',
+    'CAB'  => ' CAB',
+    'CAC'  => ' CAC',
+    'CAD'  => ' CAD',
+    'CB'   => ' CB ',
+    'CBA'  => ' CBA',
+    'CBB'  => ' CBB',
+    'CBC'  => ' CBC',
+    'CBD'  => ' CBD',
+    'CD'   => ' CD ',
+    'CD1'  => ' CD1',
+    'CD2'  => ' CD2',
+    'CE'   => ' CE ',
+    'CE1'  => ' CE1',
+    'CE2'  => ' CE2',
+    'CE3'  => ' CE3',
+    'CG'   => ' CG ',
+    'CG1'  => ' CG1',
+    'CG2'  => ' CG2',
+    'CGA'  => ' CGA',
+    'CGD'  => ' CGD',
+    'CH2'  => ' CH2',
+    'CHA'  => ' CHA',
+    'CHB'  => ' CHB',
+    'CHC'  => ' CHC',
+    'CHD'  => ' CHD',
+    'CMA'  => ' CMA',
+    'CMB'  => ' CMB',
+    'CMC'  => ' CMC',
+    'CMD'  => ' CMD',
+    'CZ'   => ' CZ ',
+    'CZ2'  => ' CZ2',
+    'CZ3'  => ' CZ3',
+    'FE'   => 'FE  ',
+    'H'    => ' H  ',
+    'HA'   => ' HA ',
+    'HB'   => ' HB ',
+    'HG'   => ' HG ',
+    'HE'   => ' HE ',
+    'HZ'   => ' HZ ',
+    'HH'   => ' HH ',
+    '1H'   => '1H  ',
+    '2H'   => '2H  ',
+    '3H'   => '3H  ',
+    '1HA'  => '1HA ',
+    '1HB'  => '1HB ',
+    '1HD'  => '1HD ',
+    '1HE'  => '1HE ',
+    '1HG'  => '1HG ',
+    '1HZ'  => '1HZ ',
+    '2HA'  => '2HA ',
+    '2HB'  => '2HB ',
+    '2HD'  => '2HD ',
+    '2HE'  => '2HE ',
+    '2HG'  => '2HG ',
+    '1HZ'  => '1HZ ',
+    '2HZ'  => '2HZ ',
+    '3HB'  => '3HB ',
+    '3HE'  => '3HE ',
+    '3HZ'  => '3HZ ',
+    'N'    => ' N  ',
+    'NA'   => ' NA ',
+    'NB'   => ' NB ',
+    'NC'   => ' NC ',
+    'ND'   => ' ND ',
+    'N A'  => ' N A',
+    'N B'  => ' N B',
+    'N C'  => ' N C',
+    'N D'  => ' N D',
+    'N1'   => ' N1 ',
+    'N2'   => ' N2 ',
+    'N3'   => ' N3 ',
+    'ND1'  => ' ND1',
+    'ND2'  => ' ND2',
+    'NE'   => ' NE ',
+    'NE1'  => ' NE1',
+    'NE2'  => ' NE2',
+    'NH1'  => ' NH1',
+    'NH2'  => ' NH2',
+    'NZ'   => ' NZ ',
+    'O'    => ' O  ',
+    'O1'   => ' O1 ',
+    'O1A'  => ' O1A',
+    'O1D'  => ' O1D',
+    'O2'   => ' O2 ',
+    'O2A'  => ' O2A',
+    'O2D'  => ' O2D',
+    'O3'   => ' O3 ',
+    'O4'   => ' O4 ',
+    'O5'   => ' O5 ',
+    'O6'   => ' O6 ',
+    'OD1'  => ' OD1',
+    'OD2'  => ' OD2',
+    'OE1'  => ' OE1',
+    'OE2'  => ' OE2',
+    'OG'   => ' OG ',
+    'OG1'  => ' OG1',
+    'OH'   => ' OH ',
+    'OXT'  => ' OXT',
+    'S'    => ' S  ',
+    'SD'   => ' SD ',
+    'SG'   => ' SG '
+);
+
+sub pdb_rename{
+  my $self = shift;
+  my $name = $self->name;
+  if(exists($pdb_atom_names{$self->name})){
+    $self->name($pdb_atom_names{$self->name});
+  }
+  return $name;
+}
+
 no Moose::Role;
 1;
 
@@ -96,7 +238,7 @@ HackaMol::Roles::PdbRole - PdbRole of lazy attributes for HackaMol atoms
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
@@ -133,6 +275,10 @@ functionality of the PdbRole may be extended in the future.  An extension
 
 =head1 METHODS
 
+=head2 pdb_rename
+
+no arguments.  Returns the current name. Renames the atom based on names used by the PDB (if exists).  This is useful for programs that render the secondary structure of molecules.
+
 =head2 aa321
 
 returns 1 letter code for amino acid. Generated from resname attribute. throws a warning and returns 'X' if residue name is unrecognized.
