@@ -1,5 +1,5 @@
 package HackaMol::Roles::PhysVecMVRRole;
-$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.032';
+$HackaMol::Roles::PhysVecMVRRole::VERSION = '0.033';
 # ABSTRACT: Provides the core of HackaMol Atom and Molecule classes.
 use Math::Vector::Real;
 use Math::Trig;
@@ -7,9 +7,28 @@ use Math::Trig;
 #use Moose::Util::TypeConstraints;
 use Moose::Role;
 use Carp;
+use Data::Structure::Util qw (unbless);
+use MooseX::Storage;
+
+#with Storage( 'format' => 'JSON', 'io' => 'File' );
 
 requires qw(_build_mass charge);
 
+#MooseX::Storage::Engine->add_custom_type_handler(
+#  'Math::Vector::Real' => (
+#      expand    => sub {my $v   = shift; Math::Vector::Real->new(@{$v})},
+#      collapse  => sub {my $mvr = shift; return (unbless($mvr)) },
+#  )
+#);
+#use Data::Dumper;
+#MooseX::Storage::Engine->add_custom_type_handler(
+#  'ArrayRef[Math::Vector::Real]' => (
+#      expand    => sub {print Dumper $_; my @vs = map {Math::Vector::Real->new(@{$_}); print $_} @$_; return [@vs] },
+#      collapse  => sub {my $a_rf = shift; my @vs = map {unbless($_)} @$a_rf; return \@vs },
+#  )
+#);
+
+
 has 't', is => 'rw', isa => 'Int|ScalarRef', default => 0;
 
 has "$_" => (
@@ -323,7 +342,7 @@ HackaMol::Roles::PhysVecMVRRole - Provides the core of HackaMol Atom and Molecul
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
